About
=====
Python client for Hadoop WebHDFS_

whoops provides both an `WebHDFS` class for programmatic access and a `whoops`
script for command line usage.

.. _WebHDFS: http://hadoop.apache.org/docs/current/hadoop-yarn/hadoop-yarn-site/WebHDFS.html
